# UTF-8 encoded polish translation file for use with Oddmuse
#
# Copyright (c) 2006 Radomir Dopieralski
# Copyright (c) 2007 Marcin Borkowski
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt .
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
$ModulesDescription .= '<p>$Id: polish-utf8.pl,v 1.5 2007/08/19 11:42:08 as Exp $</p>';
%Translate = split(/\n/,<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.
Nie wolno Ci czytać tej strony: użytkownik, numer ip lub sieć jest zablokowana.
Login
Zaloguj
Error

%s calls
%s odwołań
Could not create %s
Nie można utworzyć %s
Invalid UserName %s: not saved.
Nieprawidłowa NazwaUżytkownika %s: nie zapisano.
UserName must be 50 characters or less: not saved
NazwaUżytkownika musi mieć nie więcej niż 50 znaków: nie zapisane.
This page contains an uploaded file:
Ta strona zawiera wgrany plik:
Recursive include of %s!
Rekurencyjna inkluzja %s!
Clear Cache
Wyczyść Cache
Main lock obtained.
Uzyskano główną blokadę.
Main lock released.
Zwolniono główną blokadę.
Journal
Dziennik
More...
Więcej...
Comments on this page
Komentarze na tej stronie
XML::RSS is not available on this system.
XML::RSS niedostępne na tym systemie.
diff
różnice
history
historia
%s returned no data, or LWP::UserAgent is not available.
%s nie zwrócił danych lub LWP:UserAgent jest niedostępny.
RSS parsing failed for %s
Parsowanie RSS nie powiodło się dla %s
No items found in %s.
Nie znaleziono elementów w %s.
 . . . . 
 . . . .
Click to edit this page
Kliknij aby edytować tę stronę
CGI Internal error: %s
Wewnętrzny błąd CGI: %s
Invalid action parameter %s
Niewłaściwy parametr działania %s
Invalid URL.
Niewłaściwy URL.
Page name is missing
Brakuje nazwy strony
Page name is too long: %s
Nazwa strony jest zbyt długa: %s
Invalid Page %s (must not end with .db)
Niewłaściwa strona %s (nie może kończyć się na .db)
Invalid Page %s (must not end with .lck)
Niewłaściwa strona %s (nie może kończyć się na .lck)
Invalid Page %s
Niewłaściwa strona %s
Preview:
Podgląd:
Preview only, not yet saved
Tylko podgląd, jeszcze nie zapisane
Please go on to %s.
Proszę przejść do %s.
All changes for %s
Wszystkie zmiany dla %s
No updates since %s
Zadnych zmian od %s
Updates since %s
Zmiany od %s
Updates in the last %s days
Zmiany w ostatnich %s dniach
Updates in the last %s day
Zmiany w ostatnim %s dniu
for %s only
tylko dla %s
List latest change per page only
Wyświetl tylko ostatnią zmianę dla każdej strony
List all changes
Wyświetl wszystkie zmiany
Skip rollbacks
Pomiń cofnięcia
Include rollbacks
Uwzględnij cofnięcia
List only major changes
Wyświetl tylko istotne zmiany
Include minor changes
Uwzględnij drobne zmiany
%s days
%s dni
List later changes
Wyświetl późniejsze zmiany
RSS

RSS with pages

RSS with pages and diff

Filters
Filtry
Title:
Tytuł:
Title and Body:
Tytuł i tekst:
Username:
Użytkownik:
Host:
Komputer:
Follow up to:

Language:
Język:
Go!
Szukaj
(minor)
(drobna)
rollback
cofnij
new
nowa
from %s
z %s
: 
: 
This page is too big to send over RSS.
Ta strona jest zbyt duża, żeby ją wysłać przez RSS.
History of %s
Historia %s
Compare
Porównaj
Deleted
Usunięta
Mark this page for deletion
Zaznacz tę stronę do usunięcia
No other revisions available
Nie ma dostępnych innych wersji
current
aktualna
Revision %s
Wersja %s
Contributors to %s
Współautorzy %s
Missing target for rollback.
Nie ma czego cofać
Target for rollback is too far back.
Zbyt stare, aby cofnąć
A username is required for ordinary users.
Zwykły użytkownik musi mieć nazwę.
Rolling back changes
Cofam zmiany
The two revisions are the same.
Te dwie wersje są identyczne.
Editing not allowed for %s.
Edycja %s niedozwolona.
Rollback to %s
Cofam do %s
%s rolled back
%s cofnięte
to %s
do %s
Index of all pages
Spis wszystkich stron
Wiki Version
Wersja Wiki
Unlock Wiki
Odblokuj Wiki
Password
Hasło
Run maintenance
Przeprowadź konserwację
Unlock site
Odblokuj serwis
Lock site
Zablokuj serwis
Install CSS
Zainstaluj CSS
Unlock %s
Odblokuj %s
Lock %s
Zablokuj %s
Administration
Administracja
Actions:
Działania:
Important pages:
Ważne strony:
To mark a page for deletion, put <strong>%s</strong> on the first line.
Aby zaznaczyć stronę do usunięcia, wpisz <strong>%s</strong> w pierwszej linii.
[Home]
[Dom]
redirected from %s
przekierowano z %s
Click to search for references to this page
Kliknij, aby szukać odniesień do tej strony
Cookie: 
Ciasteczko:
Warning
Ostrzeżenie
Database is stored in temporary directory %s
Baza danych przechowywana w katalogu tymczasowym %s
%s seconds
%s sekund
The same page on other sites:
Ta sama strona gdzie indziej
EditNearLinks
EdytujBliskieLinki
Last edited
Ostatnio edytowane
Edited
Edytowane
by %s
przez %s
(diff)
(różnice)
Edit revision %s of this page
Edytuj wersję %s tej strony
Edit this page
Edytuj tę stronę
e
e
This page is read-only
Ta strona jest tylko do odczytu
View other revisions
Zobacz inne wersje
View current revision
Zobacz aktualną wersję
View all changes
Zobacz wszystkie zmiany
View contributors
Zobacz współautorów
Homepage URL:
URL strony domowej:
s
s
Save
Zapisz
p
p
Preview
Podgląd
Search:
Szukaj:
f
f
Replace:
Zamień:
Delete

Validate HTML
Sprawdź HTML
Validate CSS
Sprawdż CSS
Last edit
Ostatnia edycja
Difference between revision %1 and %2
Różnice (pomiędzy wersjami %1 i %2)
revision %s
wersja %s
current revision
aktualna wersja
Last major edit (%s)
Ostatnia główna edycja
later minor edits
Ostatnia pomniejsza edycja
No diff available.
Różnice niedostępne.
Old revision:
Stara wersja:
Changed:
Zmienione:
Deleted:
Skasowane:
Added:
Dodane:
to
do
Revision %s not available
Wersja %s niedostępna
showing current revision instead
pokazuję aktualną wersję zamiast niej
Showing revision %s
Wyświetlana wersja %s
Cannot save a nameless page.
Nie można zapisać strony bez nazwy.
Cannot save a page without revision.
Nie można zapisać strony bez wersji.
Cannot open %s
Nie można otworzyć %s
Cannot write %s
Nie można zapisać %s
Cannot create %s
Nie można utworzyć %s
Could not get %s lock
Nie można zablokować %s
The lock was created %s.
Blokada utworzona %s
This operation may take several seconds...
Ta operacja może potrwać kilka sekund...
Forced unlock of %s lock.
Wymuszone odblokowanie %s.
No unlock required.
Odblokowanie nie jest konieczne.
%s hours ago
%s godzin temu
1 hour ago
1 godzinę temu
%s minutes ago
%s minut temu
1 minute ago
1 minutę temu
%s seconds ago
%s sekund temu
1 second ago
1 sekundę temu
just now
przed chwilką
Edit Denied
Edycja Niedozwolona
Editing not allowed: user, ip, or network is blocked.
Edycja zabroniona: użytkownik, numer ip lub sieć zablokowane.
Contact the wiki administrator for more information.
Skontaktuj się z administratorem wiki aby uzyskać więcej informacji.
The rule %s matched for you.
Reguła %s została dopasowana do Ciebie.
See %s for more information.
Zobacz %s aby uzyskać więcej informacji.
Editing not allowed: %s is read-only.
Edycja zabroniona: %s jest tylko do odczytu.
Only administrators can upload files.
Tylko administrator może wgrywać pliki.
Editing revision %s of
Edytowanie wersji %s strony 
Editing %s
Edytowanie %s
Editing old revision %s.
Edytowanie starej wersji %s.
Saving this page will replace the latest revision with this text.
Zapisanie tej strony zastąpi ostatnią wersję tym tekstem.
Summary:
Streszczenie:
This change is a minor edit.
Ta zmiana jest drobna.
Cancel
Anuluj
Replace this file with text
Zastąp ten plik tekstem
Replace this text with a file
Zastąp ten tekst plikiem
File to upload: 
Plik do wgrania:
Files of type %s are not allowed.
Pliki typu %s są niedozwolone.
Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Twoje hasło jest zapisane w ciasteczku, jeśli masz włączoną ich obsługę. Ciasteczka mogą zaginąć jeśli łączysz się z innego komputera, innego konta lub używasz innego programu.
You are currently an administrator on this site.
Jesteś obecnie administratorem tej strony.
You are currently an editor on this site.
Jesteś obecnie redaktorem tej strony.
You are a normal user on this site.
Jesteś zwyczajnym użytkownikiem.
Your password does not match any of the  administrator or editor passwords.
Twoje hasło nie pasuje do żadnego z haseł edytora ani administratora.
Password:
Hasło:
This site does not use admin or editor passwords.
Ta strona nie używa haseł redaktora ani administratora.
This operation is restricted to site editors only...
Ta operacja jest dozwolona tylko dla redaktorów strony.,,
This operation is restricted to administrators only...
Ta operacja jest dozwolona tylko dla administratorów strony...
SampleUndefinedPage
PrzykładNiezdefiniowanejStrony
Sample_Undefined_Page
Przykład_Niezdefiniowanej_Strony
Rule "%1" matched "%2" on this page.
Reguła "%1" pasuje do "%2" na tej stronie.
Reason: %s.
Przyczyna: %s.
Reason unknown.
Przyczyna nieznana.
Without normal pages
Bez zwykłych stron
Include normal pages
Ze zwykłymi stronami
Without permanent anchors
Bez stałych odnośników
Include permanent anchors
Ze stałymi odnośnikami
Without near pages
Bez bliskich stron
Include near pages
Z bliskimi stronami
(for %s)
(dla %s)
Filter:
Filtr:
%s pages found.
znaleziono %s stron.
Replaced: %s
Zamieniono: %s
Search for: %s
Szukaj: %s
View changes for these pages
Zobacz zmiany dla tych stron
Search sites on the %s as well
Szukaj stron także na %s
and
oraz
or
lub
Fetching results from %s:
Pobieram wyniki z %s:
Near pages:
Bliskie strony:
last updated
ostatnio zmieniane
by
autorstwa
Transfer Error: %s
Bląd przesyłania: %s
Browser reports no file info.
Przeglądarka nie zwraca informacji o pliku.
Browser reports no file type.
Przeglądarka nie zwraca typu pliku.
The page contains banned text.
Strona zawiera zabroniony tekst.
No changes to be saved.
Nie ma żadnych zmian do zapisania.
This page was changed by somebody else %s.
Ta strona została zmieniona przez kogoś innego.
The changes conflict.  Please check the page again.
Wystąpił konflikt zmian. Proszę sprawdzić stronę ponownie.
Please check whether you overwrote those changes.
Prosze sprawdzić, czy nadpisałeś te zmiany.
Anonymous
Anonimowy
Cannot delete the index file %s.
Nie można skasować pliku indeksu %s.
Please check the directory permissions.
Proszę sprawdzić uprawnienia do katalogu.
Your changes were not saved.
Twoje zmiany nie zostały zapisane.
Could not get a lock to merge!
Nie można uzyskać blokady, aby połączyć zmiany.
you
ty
ancestor
przodek
other
inny
Run Maintenance
Przeprowadź konserwację
Maintenance not done.
Konserwacja nie przeprowadzona.
(Maintenance can only be done once every 12 hours.)
(Konserwacja może być przeprowadzona tylko raz na 12 godzin).
Remove the "maintain" file or wait.
Usuń plik "maintain" lub czekaj.
Expiring keep files and deleting pages marked for deletion
Przedawnianie plików staroci i usuwanie stron zaznaczonych do usunięcia
not deleted: 
nie skasowane:
deleted
skasowane
Moving part of the %s log file.
Przenoszenie części pliku logów %s.
Could not open %s log file
Nie można otworzyć pliku logów %s.
Error was
Błędem było
Note: This error is normal if no changes have been made.
Uwaga: Ten błąd jest normalny, jeśli nie było żadnych zmian.
Moving %s log entries.
Przenoszenie %s wpisów logów.
Getting page index file for %s.
Pobieranie pliku indeksu dla %s.
Set or Remove global edit lock
Ustaw lub zwolnij globalną blokadę edycji
Edit lock created.
Ustawiono blokadę edycji.
Edit lock removed.
Zwolniono blokadę edycji.
Set or Remove page edit lock
Ustaw lub zwolnij blokadę edycji strony
Lock for %s created.
Ustawiono blokadę dla %s
Lock for %s removed.
Zwolniono blokadę dla %s
Displaying Wiki Version
Wyświetlanie wersji Wiki
Show dependencies
Pokaż zależności
Inter links:
Wewnętrze odnośniki:
Near links:
Bliskie odnośniki:
Show parsed link data
Pokaż sparsowane dane odnośników
Too many connections by %s
Zbyt dużo połączeń z %s
Please do not fetch more than %1 pages in %2 seconds.
Proszę nie pobierać więcej niż %1 stron w ciągu %2 sekund.
Check whether the web server can create the directory %s and whether it can create files in it.
Sprawdź czy serwer WWW może utworzyć katalog %s, oraz czy może tworzyć w nim pliki.
anchor first defined here: %s
odnośnik zdefiniowano uprzednio tutaj: %s
Click to search for references to this permanent anchor
Kliknij aby poszukać odniesień do tego stałego odnośnika
the page %s also exists
strona %s także istnieje
Copy one of the following stylesheets to %s:
Skopiuj jeden z następujących arkuszy styli do %s:
Deleting %s
Kasowanie %s
Deleted %s
Skasowano %s
Renaming %1 to %2.
Zmienianie nazwy %s na %s.
The page %s does not exist
Strona %s nie istnieje
The page %s already exists
Strona %s już istnieje
Cannot rename %1 to %2
Nie można zmienić nazwy %1 na %2
Renamed to %s
Zmieniono nazwę na %s
Renamed from %s
Zmieniono nazwę z %s
Renamed %1 to %2.
Zmieniono nazwę z %1 na %2.
Immediately delete %s
Niezwłocznie skasuj %s
Rename %s to:
Zmień nazwę %s na:
Learn more...
Dowiedz się więcej...
Complete Content
Całkowita zawartość
The main page is %s.
Główną stroną jest %s.
Archive:

Rebuild BackLink database
Przebuduj spis linkujących
Internal Page: 
Strona Wewnętrzna: 
Pages that link to this page
Strony linkujące do tej strony
Cannot highlight the language %s.
Nie można pokolorować źródła dla języka %s.
Recent Visitors
Ostatni Odwiedzający
some action
jakieś działanie
was here
był tutaj
and read
i czytał
Illegal year value: Use 0001-9999
Niedozwolony rok: Użyj 0001-9999
The match parameter is missing.
Brakuje parametru dopasowania.
Page Collection for %s
Zbiór stron dla %s
Previous
Poprzedni
Next
Następny
Calendar %s
Kalendarz %s
Su
nd
Mo
pn
Tu
wt
We
śr
Th
cz
Fr
pt
Sa
so
January
styczeń
February
luty
March
marzec
April
kwiecień
May
maj
June
czerwiec
July
lipiec
August
sierpień
September
wrzesień
October
październik
November
listopad
December
grudzień
set %s
ustaw %s
unset %s
anuluj ustawienie %s
Clustermap
Mapa klastrów
Pages without a Cluster
Strony bez klastra
Comments on 
Komentarze na
Comment on 
Skomentuj 
Compilation for %s
Kompilacja dla %s
Compilation tag is missing a regular expression.
Brak wyrażenia regularnego w znaczniku kompilacji.
List spammed pages

Despamming pages
Odspamowywanie stron
Spammed pages

Cannot find revision %s.
Nie można znaleźć wersji %s.
Revert to revision %1: %2
Przywróć wersję %1: %2
Marked as %s.
Oznaczony jako %s.
Cannot find unspammed revision.
Nie można znaleźć czystej wersji.
Recover Draft
Odzyskaj brudnopis
No text to save
Brak tekstu do zapisania
Draft saved
Brudnopis zapisany
Draft recovered
Brudnopis odzyskany
No draft available to recover
Brak brudnopisu do odzyskania
Save Draft
Zapisz brudnopis
Draft Cleanup
Czyszczenie brudnopisu
%1 was last modified %2 and was kept
%1 było ostatnio modyfikowane %2 i zostało zachowane
%1 was last modified %2 and was deleted
%1 było ostatnio modyfikowane %2 i zostało skasowane
Unable to delete draft %s
Nie udało się skasować brudnopisu %s
Add Comment
Dodaj komentarz
ordinary changes
zwykłe zmiany
Matching page names:

Footnotes:
Przypisy:
Could not find %1.html template in %2
Nie można znaleźć szablonu %1.html w %2
Only Editors are allowed to see this hidden page.
Tylko redaktorom wolno oglądać tę ukrytą stronę.
Only Admins are allowed to see this hidden page.
Tylko administratorom wolno oglądać tę ukrytą stronę.
Index
Indeks
Languages:
Języki:
Show!
Pokaż!
Define
Zdefiniuj
Full Link List
Pełna lista odnośników
Template without parameters
Szablon bez parametrów
The template %s is either empty or does not exist.
Szablon %s albo jest pusty, albo nie istnieje.
 -- defined on %s
 -- zdefiniowane na %s
Local names defined on %1: %2
Lokalne nazwy zdefiniowane na %1: %2
Register for %s
Zarejestruj dla %s
Please choose a username of the form "FirstLast" using your real name.
Proszę wybrać nazwę użytkownika w postaci "ImięNazwisko".
The passwords do not match.
Hasła nie zgadzają się.
The password must be at least %s characters.
Hasło musi mieć co najmniej %s znaków.
That email address is invalid.
Adres poczty elektronicznej jest niepoprawny.
The username %s has already been registered.
Nazwa użytkownika %s jest już zarejestrowana.
Your registration for %s has been submitted.
Twoja rejestracja dla %s została wysłana.
Please allow time for the webmaster to approve your request.
Proszę dać administratorowi czas na potwierdzenie.
An email has been sent to "%s" with further instructions.
Wysłano e-mail do "%s" z dalszymi instrukcjami.
There was an error saving your registration.
Wystąpił błąd podczas zapisywania rejestracji.
An account was created for %s.
Konto dla %s zostało utworzone.
Login to %s
Zaloguj się do %s
Username and/or password are incorrect.
Nazwa użytkownika i/lub hasło są niepoprawne.
Logged in as %s.
Zalogowano jako %s.
Logout of %s
Wylogowanie %s
Logout of %s?
Wylogować %s?
Logged out of %s
Wylogowano %s
You are now logged out.
Jesteś teraz wylogowany.
Register a new account
Zarejestruj nowe konto
Logout
Wyloguj
Who am I?
Kim jestem?
Forgot your password?
Zapomniałeś hasła?
Change your password
Zmień hasło
Approve pending registrations
Potwierdź oczekujące rejestracje
Confirm Registration for %s
Potwierdź rejestrację dla %s
%s, your registration has been approved. You can now use your password to login and edit this wiki.
%s, twoja rejestracja została potwierdzona. Możesz teraz użyć swojego hasła, żeby się zalogować i edytować to wiki.
Confirmation failed.  Please email %s for help.
Potwierdzenie nie powiodło się. Proszę wysłać e-maila do %s, aby uzyskać pomoc.
Who Am I?
Kim jestem?
You are logged in as %s.
Jesteś zalogowany jako %s.
You are not logged in.
Nie jesteś zalogowany.
Reset Password
Zresetuj hasło
The password for %s was reset.  It has been emailed to the address on file.
Hasło dla %s zostało zresetowane. Nowe hasło zostało wysłane pocztą.
There was an error resetting the password for %s.
Nastąpił błąd podczas resetowania hasła dla %s.
The username "%s" does not exist.
Nazwa użytkonika "%s" nie istnieje.
Reset Password for %s
Zresetuj hasło dla %s
Reset Password?
Zresetować hasło?
Change Password for %s
Zmień hasło dla %s
Change Password?
Zmienić hasło?
Your current password is incorrect.
Twoje obecne hasło jest nieprawidłowe.
Your password has been changed.
Twoje hasło zostało zmienione.
Approve Pending Registrations for %s
Potwierdź oczekujące rejestracje dla %s
%s has been approved.
%s zostało potwierdzone.
There was an error approving %s.
Nastąpił błąd przy potwierdzaniu %s.
<ul>
<ul>
<li>%1 - %2</li>
<li>%1 - %2</li>
</ul>
</ul>
There are no pending registrations.
Nie ma oczekujących rejestracji.
%s is not a legal name for a namespace
%s nie jest dozwoloną nazwą przestrzeni nazw
 (create locally)
 (utwórz lokalnie)
image
obrazek
download
pobieranie
Clearing Cache
Czyszczenie pamięci podręcznej
Done.
Gotowe.
Generating Link Database
Generownie bazy danych odnośników
The 404 handler extension requires the link data extension (links.pl).
Rozszerzenie obsługi 404 wymaga rozszerzenia danych o odnośnikach (links.pl).
LocalMap
MapaLokalna
No page id for action localmap
Nie ma identyfikatora strony dla działania mapy lokalnej
Requested page %s does not exist
Żądana strona %s nie istnieje
Local Map for %s
Mapa lokalna dla %s
view
zobacz
Self-ban by %s
Samo-zablokowano przez %s
You have banned your own IP.
Zablokowałeś własny numer ip.
Orphan List
Lista Sierot
Trail: 
Ślad:
None
Żaden
Type
Typ
Permalink to "%s"
Stały odnośnik do "%s"
There was an error generating the pdf for %s.  Please report this to webmaster, but do not try to download again as it will not work.
Nastąpił bład podczas generowania pdf dla %s. Proszę zgłosić to do administratora, ale nie próbować pobierać ponownie, gdyż to nie zadziała.
Someone else is generating a pdf for %s.  Please wait a minute and then try again.
Ktoś inny generuje pdf dla %s. Proszę poczekać minutę i spróbować ponownie.
Download this page as PDF
Pobierz tę stronę jako PDF
Portrait
Portret
Publish %s
Opublikuj %s
No target wiki was specified in the config file.
Docelowa wiki nie została określona w pliku konfiguracji.
The target wiki was misconfigured.
Docelowa wiki jest źle skonfigurowana.
You did not answer correctly.
Nie odpowiedziałes poprawnie.
Use the back button to return the previous page and try again.
Użyj przycisku powrotu, by wrócić do poprzedniej strony, i spróbuj ponownie.
To save this page you must answer this question:
Aby zapisać tę stronę, musisz odpowiedzieć na pytanie:
Referrers
Odniesienia
All Referrers
Wszystkie odniesienia
Tag
Znaczniki
Rebuild index for searching
Przebuduj indeks przeszukiwania
Tag Cloud
Chmura znaczników
Search::FreeText is not available on this system.
Search::FreeText jest niedostępny w tym systemie.
Rebuilding index not done.
Przebudowywanie indeksu nie zakończone.
(Rebuilding the index can only be done once every 12 hours.)
(Przebudowa indeksu może być dokonana raz na 12 godzin).
 ... 
 ... 
Search term missing.
Brak frazy wyszukiwania.
Result pages: 
Strony wyniku:
(%s results)
(%s wyników)
Tags:
Znaczniki:
Tags: %s.
Znaczniki: %s.
No tags
Brak znaczników
Slideshow:%s
Pokaz slajdów: %s
Index of all small pages
Spis wszystkich małych stron
Static Copy
Kopia Statyczna
Back to %s
Wróć do %s
Copy to %1 succeeded: %2.
Kopiowanie do %1 udane: %2.
Copy to %1 failed: %2.
Kopiowanie do %1 nie powiodło się: %2.
Alternatively, use one of the following templates:
Ewentualnie użyj jednego z poniższych szablonów:
Thread: %s
Wątek: %s
ID parameter is missing.
Brak parametru ID.
Thread %s does not exist.
Watek %s nie istnieje.
Page %s does not contain a thread.
Strona %s nie zawiera wątka.
Add
Dodaj
URL parameter is missing.
Nrak parametru URL.
Add to %s thread
Dodaj do wątku %s
Below:
Poniżej:
URL:
URL:
Name:
Nazwa:
Too many instances.  Only %s allowed.
Zbyt wiele instancji - może być tylko %s.
Please try again later. Perhaps somebody is running maintenance or doing a long search. Unfortunately the site has limited resources, and so we must ask you for a bit of patience.
Prosimy spróbować później.  Być może ktoś dokonuje konserwacji serwisu lub jest w trakcie długiego wyszukiwania.  Niestety, nasz serwis ma ograniczone zasoby, więc musimy prosić o odrobinę cierpliwości.
Contents
Zawartość
Create a new page for today

This page is a translation of %s. 
Ta strona jest tłumaczeniem %s.
The translation is up to date.
Tłumaczenie jest aktualne.
The translation is outdated.
Tłumaczenie jest przestarzałe.
The page does not exist.
Strona ta nie istnieje.
http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s
http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s
http://www.amazon.com/exec/obidos/ISBN=%s
http://www.amazon.com/exec/obidos/ISBN=%s
alternate
alternatywne
http://www.pricescan.com/books/BookDetail.asp?isbn=%s
http://www.pricescan.com/books/BookDetail.asp?isbn=%s
search
szukanie
Wanted Pages
Porządane strony
%s pages
%s stron
%s, referenced from:
%s, wspomniana na:
Upload of %s file
Wgranie pliku %s
Blog
Blog
Matching pages:
Pasującestrony:
New
Nowy
Edit %s.
Edycja %s.
Title: 
Tytuł:
Tags: 
Znaczniki:
END_OF_TRANSLATION
